@@ -16,17 +16,15 @@
  * Author: Meg Ford <megford@gnome.org>
  *
  */
- 
-imports.gi.versions.Gst = '1.0';
 
 const Gettext = imports.gettext;
 const _ = imports.gettext.gettext;
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject; 
+const GObject = imports.gi.GObject;
 const Gst = imports.gi.Gst;
 const GstPbutils = imports.gi.GstPbutils;
-
+const Lang = imports.lang;
 const Signals = imports.signals;
 
 const Listview = imports.listview;
