@@ -55,7 +55,7 @@ const InfoDialog = new Lang.Class({
         let cancelButton = new Gtk.Button({ label: _("Cancel"),
                                             margin_bottom: 4,
                                             margin_top: 6,
-                                            margin_right: 6 });
+                                            margin_start: 6 });
         cancelButton.connect("clicked", Lang.bind(this, this.onCancelClicked));
         cancelToolbar.pack_end(cancelButton, false, true, 0);
         cancelButton.show();
@@ -68,8 +68,8 @@ const InfoDialog = new Lang.Class({
         
         let button = new Gtk.Button({ label: _("Done"),
                                       margin_bottom: 4,
-                                      margin_top: 6,
-                                      margin_right: 6 });
+                                      margin_end: 6,
+                                      margin_top: 6 });
         button.connect("clicked", Lang.bind(this, this.onDoneClicked));
         buttonToolbar.pack_end(button, false, true, 0);
         button.show();
@@ -81,10 +81,10 @@ const InfoDialog = new Lang.Class({
                                    halign: Gtk.Align.CENTER,
                                    row_spacing: 6,
                                    column_spacing: 24,
-                                   margin_top: 12,
-                                   margin_left: 24,
-                                   margin_right: 24,
-                                   margin_bottom: 12 });
+                                   margin_bottom: 12,
+                                   margin_end: 24,
+                                   margin_start: 24,
+                                   margin_top: 12 });
 
         let contentArea = this.widget.get_content_area();
         contentArea.pack_start(grid, true, true, 2);
