@@ -59,6 +59,7 @@ let view = null;
 let volumeValue = [];
 let wave = null;
 
+const rtl = Gtk.Widget.get_default_direction() == Gtk.TextDirection.RTL;
 
 const ActiveArea = {
     RECORD: 0,
@@ -97,10 +98,10 @@ const MainWindow = new Lang.Class({
         play = new Play.Play();
 
         params = Params.fill(params, { title: GLib.get_application_name(),
+                                       default_height: 480,
+                                       default_width: 780,
                                        hexpand: true,
-                                       vexpand: true,
-                                       default_width: 800,
-                                       default_height: 480 });
+                                       vexpand:true });
         this.parent(params);
 
         header = new Gtk.HeaderBar({ hexpand: true,
@@ -204,19 +205,18 @@ const MainView = new Lang.Class({
     _formatTime: function(unformattedTime) {
         this.unformattedTime = unformattedTime;
         let seconds = Math.floor(this.unformattedTime);
-        let hours = parseInt( seconds / Math.pow(_TIME_DIVISOR, 2));
-        let hoursString = "00"
+        let hours = parseInt(seconds / Math.pow(_TIME_DIVISOR, 2));
+        let hoursString = ""
 
         if (hours > 10)
-            hoursString = hours
+            hoursString = hours + ":"
         else if (hours < 10 && hours > 0)
-            hoursString = "0" + hours
+            hoursString = "0" + hours + ":"
 
-        let minuteString = parseInt( seconds / _TIME_DIVISOR ) % _TIME_DIVISOR;
-        let secondString = seconds % _TIME_DIVISOR;
+        let minuteString = parseInt(seconds / _TIME_DIVISOR) % _TIME_DIVISOR;
+        let secondString = parseInt(seconds % _TIME_DIVISOR);
         let timeString =
             hoursString +
-            ":" +
             (minuteString < 10 ? "0" + minuteString : minuteString)+
             ":" +
             (secondString < 10 ? "0" + secondString : secondString);
@@ -265,11 +265,8 @@ const MainView = new Lang.Class({
         volumeValue.push({ record: micVolume, play: playVolume });
         activeProfile = Application.application.getPreferences();
 
-        this.recordGrid = new Gtk.Grid({ orientation: Gtk.Orientation.HORIZONTAL,
-                                         height_request: 36,
-                                         width_request: 775,
-                                         hexpand: true,
-                                         name: "recordGrid" });
+        this.recordGrid = new Gtk.Grid({ name: "recordGrid",
+                                         orientation: Gtk.Orientation.HORIZONTAL });
         this.groupGrid.add(this.recordGrid);
 
         this.widgetRecord = new Gtk.Toolbar({ show_arrow: false,
@@ -284,16 +281,16 @@ const MainView = new Lang.Class({
         this.widgetRecord.insert(this._groupRecord, -1);
 
         this.recordTextLabel = new Gtk.Label({ margin_bottom: 4,
-                                               margin_top: 6,
-                                               margin_left: 6,
-                                               margin_right: 6 });
+                                               margin_end: 6,
+                                               margin_start: 6, 
+                                               margin_top: 6 });
         this.recordTextLabel.label = _("Recording…");
         this._boxRecord.pack_start(this.recordTextLabel, false, true, 0);
 
         this.recordTimeLabel = new Gtk.Label({ margin_bottom: 4,
-                                               margin_top: 6,
-                                               margin_left: 6,
-                                               margin_right: 6 });
+                                               margin_end: 6,
+                                               margin_start: 6, 
+                                               margin_top: 6});
 
         this._boxRecord.pack_start(this.recordTimeLabel, false, true, 0);
 
@@ -302,13 +299,13 @@ const MainView = new Lang.Class({
 
         // finish button (stop recording)
         let stopRecord = new Gtk.Button({ label: _("Done"),
-                                          margin_bottom: 4,
-                                          margin_top: 6,
-                                          margin_left: 6,
-                                          margin_right: 6,
-                                          valign: Gtk.Align.CENTER,
                                           halign: Gtk.Align.FILL,
-                                          hexpand: true });
+                                          valign: Gtk.Align.CENTER,
+                                          hexpand: true,
+                                          margin_bottom: 4,
+                                          margin_end: 6,
+                                          margin_start: 6, 
+                                          margin_top: 6 });
         stopRecord.get_style_context().add_class('text-button');
         stopRecord.connect("clicked", Lang.bind(this, this.onRecordStopClicked));
         this.toolbarStart.pack_start(stopRecord, true, true, 0);
@@ -317,7 +314,6 @@ const MainView = new Lang.Class({
 
     scrolledWinAdd: function() {
         this._scrolledWin = new Gtk.ScrolledWindow({ shadow_type: Gtk.ShadowType.IN,
-                                                     width_request: 775,
                                                      vexpand: true });
         this._scrolledWin.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC);
         this.scrollbar = this._scrolledWin.get_vadjustment();
@@ -361,7 +357,7 @@ const MainView = new Lang.Class({
             this.listBox.set_selection_mode(Gtk.SelectionMode.SINGLE);
             this.listBox.set_header_func(null);
             this.listBox.set_activate_on_single_click(true);
-            this.listBox.connect("row-selected", Lang.bind(this,
+            this.listBox.connect("row-activated", Lang.bind(this,
                 function(){
                     this.rowGridCallback(this.listBox.get_selected_row())
                 }));
@@ -371,38 +367,36 @@ const MainView = new Lang.Class({
             this._files = list.getFilesInfoForList();
 
             for (let i = this._startIdx; i <= this._endIdx; i++) {
-                this.rowGrid = new Gtk.Grid({ orientation: Gtk.Orientation.VERTICAL,
+                this.rowGrid = new Gtk.Grid({ name: i.toString(),
                                               height_request: 45,
-                                              width_request: 775,
-                                              vexpand: true,
-                                              name: i.toString() });
+                                              orientation: Gtk.Orientation.VERTICAL,
+                                              hexpand: true,
+                                              vexpand: true });
                 this.rowGrid.set_orientation(Gtk.Orientation.HORIZONTAL);
                 this.listBox.add(this.rowGrid);
                 this.rowGrid.show();
-                let rtl = Gtk.Widget.get_default_direction() == Gtk.TextDirection.RTL;
 
                 this.placeholderImage = Gtk.Image.new();
                 this.placeholderImage.set_from_icon_name(rtl ? 'media-playback-start-rtl-symbolic' :
                                                             'media-playback-start-symbolic',
                                                          Gtk.IconSize.BUTTON);
-                this._placeholderButton = new Gtk.Button({ hexpand: true,
-                                                           vexpand: true,
-                                                           name: "PlaceholderButton" });
+                this._placeholderButton = new Gtk.Button({ name: "PlaceholderButton",
+                                                           hexpand: true,
+                                                           vexpand: true });
                 this._placeholderButton.set_image(this.placeholderImage);
                 this.rowGrid.attach(this._placeholderButton, 0, 0, 2, 2);
                 this._placeholderButton.set_no_show_all(true);
                 this.placeholderImage.show();
                 this._placeholderButton.show();
-                //this._placeholderButton.get_style_context().add_class("dim-label");
 
                 // play button
                 this.playImage = Gtk.Image.new({ name: "PlayImage" });
                 this.playImage.set_from_icon_name(rtl ? 'media-playback-start-rtl-symbolic' :
                                                         'media-playback-start-symbolic',
                                                   Gtk.IconSize.BUTTON);
-                this._playListButton = new Gtk.Button({ hexpand: true,
-                                                        vexpand: true,
-                                                        name: "PlayButton" });
+                this._playListButton = new Gtk.Button({ name: "PlayButton",
+                                                        hexpand: true,
+                                                        vexpand: true });
                 this._playListButton.set_image(this.playImage);
                 this._playListButton.set_tooltip_text(_("Play"));
                 this.rowGrid.attach(this._playListButton, 0, 0, 2, 2);
@@ -420,9 +414,9 @@ const MainView = new Lang.Class({
                 // pause button
                 this.pauseImage = Gtk.Image.new();
                 this.pauseImage.set_from_icon_name('media-playback-pause-symbolic', Gtk.IconSize.BUTTON);
-                this._pauseListButton = new Gtk.Button({ hexpand: true,
-                                                         vexpand: true,
-                                                         name: "PauseButton" });
+                this._pauseListButton = new Gtk.Button({ name: "PauseButton",
+                                                         hexpand: true,
+                                                         vexpand: true });
                 this._pauseListButton.set_image(this.pauseImage);
                 this._pauseListButton.set_tooltip_text(_("Pause"));
                 this.rowGrid.attach(this._pauseListButton, 0, 0, 2, 2);
@@ -433,82 +427,79 @@ const MainView = new Lang.Class({
                         this.onPause(row);
                     }));
 
-                this._fileName = new Gtk.Label({ use_markup: true,
+                this._fileName = new Gtk.Label({ name: "FileNameLabel",
+                                                 ellipsize: rtl ? Pango.EllipsizeMode.START : Pango.EllipsizeMode.END,
                                                  halign: Gtk.Align.START,
                                                  valign: Gtk.Align.START,
-                                                 ellipsize: rtl ? Pango.EllipsizeMode.START : Pango.EllipsizeMode.END,
-                                                 xalign: 0,
-                                                 width_chars: 35,
+                                                 margin_start: 15,
                                                  margin_top: 5,
-                                                 margin_left: rtl ? 0 : 15,
-                                                 margin_right: rtl ? 15 : 0,
-                                                 name: "FileNameLabel" });
+                                                 use_markup: true,
+                                                 width_chars: 35,
+                                                 xalign: 0 });
                 let markup = ('<b>'+ this._files[i].fileName + '</b>');
                 this._fileName.label = markup;
                 this._fileName.set_no_show_all(true);
                 this.rowGrid.attach(this._fileName, 3, 0, 10, 3);
                 this._fileName.show();
 
-                this._playLabelBox = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL,
-                                                   name: "PlayLabelBox",
+                this._playLabelBox = new Gtk.Box({ name: "PlayLabelBox",
+                                                   orientation: Gtk.Orientation.HORIZONTAL,
                                                    height_request: 45 });
                 this.rowGrid.attach(this._playLabelBox, 3, 1, 5, 1);
                 this._playLabelBox.show();
-                this.playDurationLabel = new Gtk.Label({ margin_left: rtl ? 0 : 15,
-                                                         margin_right: rtl ? 15 : 0,
+                this.playDurationLabel = new Gtk.Label({ name: "PlayDurationLabel",
                                                          halign: Gtk.Align.END,
                                                          valign: Gtk.Align.END,
-                                                         margin_top: 5,
-                                                         name: "PlayDurationLabel" });
+                                                         margin_start: 15,
+                                                         margin_top: 5 });
                 this.fileDuration = this._formatTime(this._files[i].duration/Gst.SECOND);
                 this.playDurationLabel.label = this.fileDuration;
                 this._playLabelBox.pack_start(this.playDurationLabel, false, true, 0);
                 this.playDurationLabel.show();
 
-                this.dividerLabel = new Gtk.Label({ halign: Gtk.Align.START,
-                                                    name: "DividerLabel",
+                this.dividerLabel = new Gtk.Label({ name: "DividerLabel",
+                                                    halign: Gtk.Align.START,
                                                     valign: Gtk.Align.END,
                                                     margin_top: 5 });
                 this.dividerLabel.label = "/";
                 this._playLabelBox.pack_start(this.dividerLabel, false, true, 0);
                 this.dividerLabel.hide();
 
-                this.playTimeLabel = new Gtk.Label({ halign: Gtk.Align.START,
-                                                     name: "PlayTimeLabel",
+                this.playTimeLabel = new Gtk.Label({ name: "PlayTimeLabel",
+                                                     halign: Gtk.Align.START,
                                                      valign: Gtk.Align.END,
+                                                     margin_end: 15,
                                                      margin_top: 5 });
                 this.playTimeLabel.label = "0:00";
                 this._playLabelBox.pack_start(this.playTimeLabel, false, true, 0);
                 this.playTimeLabel.hide();
 
                 //Date Modified label
-                this.dateModifiedLabel = new Gtk.Label({ margin_left: 15,
-                                                         margin_right: 15,
+                this.dateModifiedLabel = new Gtk.Label({ name: "dateModifiedLabel",
                                                          halign: Gtk.Align.END,
-                                                         valign: Gtk.Align.CENTER,
-                                                         margin_top: 5,
-                                                         name: "dateModifiedLabel" });
+                                                         valign: Gtk.Align.END,
+                                                         margin_start: 15,
+                                                         margin_top: 5 });
                 this.dateModifiedLabel.label = this._files[i].dateModified;
                 this.dateModifiedLabel.get_style_context().add_class('dim-label');
+                this.dateModifiedLabel.set_no_show_all(true);
                 this.rowGrid.attach(this.dateModifiedLabel, 3, 1, 6, 1);
                 this.dateModifiedLabel.show();
 
-                this.waveFormGrid = new Gtk.Grid({ orientation: Gtk.Orientation.VERTICAL,
-                                                   height_request: 45,
-                                                   width_request: 300,
-                                                   valign: Gtk.Align.FILL,
+                this.waveFormGrid = new Gtk.Grid({ name: "WaveFormGrid",
                                                    hexpand: true,
                                                    vexpand: true,
-                                                   name: "WaveFormGrid" });
+                                                   orientation: Gtk.Orientation.VERTICAL,
+                                                   valign: Gtk.Align.FILL });
                 this.waveFormGrid.set_no_show_all(true);
                 this.rowGrid.attach(this.waveFormGrid, 12, 1, 17, 2);
                 this.waveFormGrid.show();
 
                 // info button
-                this._info = new Gtk.Button({ hexpand: false,
+                this._info = new Gtk.Button({ name: "InfoButton",
+                                              hexpand: false,
                                               vexpand: true,
-                                              margin_right: 2,
-                                              name: "InfoButton" });
+                                              margin_end: 2 });
                 this._info.image = Gtk.Image.new_from_icon_name("dialog-information-symbolic", Gtk.IconSize.BUTTON);
                 this._info.connect("clicked", Lang.bind(this,
                     function() {
@@ -523,9 +514,9 @@ const MainView = new Lang.Class({
                 this._info.hide();
 
                 // delete button
-                this._delete = new Gtk.Button({ hexpand: false,
-                                                margin_left: 2,
-                                                name: "DeleteButton" });
+                this._delete = new Gtk.Button({ name: "DeleteButton",
+                                                hexpand: false,
+                                                margin_start: 2, });
                 this._delete.image = Gtk.Image.new_from_icon_name("user-trash-symbolic", Gtk.IconSize.BUTTON);
                 this._delete.connect("clicked", Lang.bind(this,
                     function() {
@@ -731,7 +722,6 @@ const MainView = new Lang.Class({
     onPlayPauseToggled: function(listRow, selFile) {
         this.activeState = play.getPipeStates();
         setVisibleID = ActiveArea.PLAY;
-        let width = listRow.get_allocated_width();
 
         if (this.activeState != PipelineStates.PLAYING) {
             play.startPlaying();
@@ -769,7 +759,6 @@ const MainView = new Lang.Class({
                         child.sensitive = true;
                     }
                 }));
-            listRow.set_property("width-request", width);
 
             if (this.activeState != PipelineStates.PAUSED) {
                 wave = new Waveform.WaveForm(this.wFGrid, selFile);
